pub enum RNGError {
GenericError(&'static str),
Uninitialized,
InsufficientSeedEntropy,
ReseedRequired,
SecurityStrengthInsufficientForAlgorithm,
KeyMaterialError(KeyMaterialError),
}Expand description
Variants
GenericError(&'static str)
Uninitialized
Attempting to extract output before the RNG has been seeded.
InsufficientSeedEntropy
The RNG has been seeded, but not sufficiently to support the requested generation operation. This includes uses in SP 800-90A mode where more output is requested than the security strength to which the RNG has been initialized.
ReseedRequired
Indicates that the RNG cannot produce any more output until it has been reseeded with fresh entropy.
SecurityStrengthInsufficientForAlgorithm
Thrown my algorithms attempting to use an RNG instance, for example for key generation or other randomness required by the algorithm, but the provided RNG is at a lower security strength than the algorithm requires.
KeyMaterialError(KeyMaterialError)